AllValidationsGetStates class
Catálogos dos estados e do Distrito Federal.
Constructors
- AllValidationsGetStates()
- Cria um acesso aos catálogos de estados por compatibilidade legada.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
listStates
→ const List<
String> - Nomes das 27 unidades federativas em ordem das siglas.
-
listStatesAcronym
→ const List<
String> - Siglas oficiais correspondentes, posição a posição, a listStates.