PasswordPolicy class
Configuração de política de senha para isPassword.
Constructors
Properties
- allowWhitespace → bool
-
Permite caracteres de espaço em branco.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int?
-
Quantidade máxima de caracteres, ou
nullpara não limitar.final - minLength → int
-
Quantidade mínima de caracteres.
final
- requireLowercase → bool
-
Exige ao menos uma letra ASCII minúscula.
final
- requireNumber → bool
-
Exige ao menos um dígito ASCII.
final
- requireSpecial → bool
-
Exige ao menos um símbolo da lista reconhecida por
isPassword.final - requireUppercase → bool
-
Exige ao menos uma letra ASCII maiúscula.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- medium → const PasswordPolicy
- Política média: maiúscula + minúscula + número, mínimo 6.
- strong → const PasswordPolicy
- Política forte: todos os requisitos, de 8 a 99 caracteres, sem espaços.
- weak → const PasswordPolicy
- Política fraca: apenas comprimento mínimo de 6.